import { Link } from "wouter";
import { motion } from "framer-motion";
import { Button } from "@/components/ui/button";
import Hero from "@/components/Hero";
import SEOHead from "@/components/SEOHead";
import { 
  Megaphone, 
  Search, 
  Share2, 
  Code, 
  Check,
  Users,
  Target,
  TrendingUp,
  Award,
  ChevronLeft,
  ChevronRight
} from "lucide-react";



const Home = () => {
  const services = [
    {
      icon: Megaphone,
      title: "Paid Media",
      description: "Strategic PPC campaigns and social advertising that maximize ROI and drive qualified leads.",
    },
    {
      icon: Search,
      title: "SEO & Content",
      description: "Organic growth strategies that build authority and drive sustainable traffic increases.",
    },
    {
      icon: Share2,
      title: "Social Strategy",
      description: "Comprehensive social media management that builds communities and drives engagement.",
    },
    {
      icon: Code,
      title: "Web Development",
      description: "Custom websites and e-commerce platforms built for performance and user experience.",
    },
  ];

  const stats = [
    { number: "200+", label: "Successful Campaigns" },
    { number: "95%", label: "Client Retention Rate" },
    { number: "R50m+", label: "Ad Spend Managed" },
    { number: "4x", label: "We deliver 4x return on ad spend on average" },
  ];

  const benefits = [
    {
      title: "Data-Driven Results",
      description: "Every decision backed by comprehensive analytics and performance metrics.",
    },
    {
      title: "Full-Service Approach", 
      description: "From strategy to execution, we handle every aspect of your digital presence.",
    },
    {
      title: "Proven Track Record",
      description: "Over 200+ successful campaigns with measurable growth for our clients.",
    },
  ];

  const homeStructuredData = {
    "@context": "https://schema.org",
    "@type": "WebPage",
    "name": "Wassp Marketing - Digital Marketing Agency",
    "description": "Transform your digital presence with expert PPC campaigns, SEO, social media strategy, and custom web development. 200+ successful campaigns with proven ROI.",
    "url": "https://wasspmarketing.com",
    "mainEntity": {
      "@type": "Organization",
      "name": "Wassp Marketing"
    }
  };

  return (
    <div>
      <SEOHead 
        title="Digital Marketing Agency | PPC, SEO, Web Development"
        description="Transform your digital presence with Wassp Marketing. Expert PPC campaigns, SEO, social media strategy, and custom web development. 200+ successful campaigns with proven ROI."
        keywords="digital marketing agency, PPC management, SEO services, social media marketing, web development, e-commerce, Google Ads, Facebook Ads"
        canonical="https://wasspmarketing.com"
        structuredData={homeStructuredData}
      />
      {/* Hero Section */}
      <Hero
        title="Ready to grow faster, rank higher, and stand out online?"
        subtitle="Wassp Marketing is Your growth partner for comprehensive digital marketing solutions that drive real results."
        backgroundGradient="from-secondary via-tertiary to-accent"
      >
        <div className="flex flex-col sm:flex-row gap-4 justify-center">
          <Link href="/contact">
            <Button 
              className="bg-primary text-secondary px-8 py-3 font-semibold hover:bg-primary/90 transition-all duration-200"
              size="lg"
            >
              Get Started Today
            </Button>
          </Link>
          <Link href="/our-results">
            <Button 
              className="bg-white text-secondary border-2 border-white px-8 py-3 font-semibold hover:bg-gray-100 transition-all duration-200"
              size="lg"
            >
              View Our Results
            </Button>
          </Link>
        </div>
      </Hero>

      {/* Services Overview */}
      <section className="py-20 bg-light">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <motion.h2 
              className="text-3xl md:text-4xl font-bold font-poppins text-secondary mb-4"
              initial={{ opacity: 0, y: 30 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.6 }}
              viewport={{ once: true }}
            >
              Achieve Real Results with Smarter Digital Marketing
            </motion.h2>
            <motion.p 
              className="text-lg text-gray-600 max-w-2xl mx-auto"
              initial={{ opacity: 0, y: 30 }}
              whileInView={{ opacity: 1, y: 0 }}
              transition={{ duration: 0.6, delay: 0.1 }}
              viewport={{ once: true }}
            >
              Struggling to scale or stand out? We'll help you get more from your marketing — from performance ads to SEO to high-converting websites — all tailored to your goals.
            </motion.p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-4 gap-8">
            {services.map((service, index) => {
              const serviceUrls = {
                "Paid Media": "/paid-media",
                "SEO & Content": "/earned-media", 
                "Social Strategy": "/earned-media",
                "Web Development": "/web-development"
              };
              
              return (
                <motion.div
                  key={service.title}
                  className="bg-white p-8 rounded-xl shadow-lg hover:shadow-xl transition-all duration-300 transform hover:-translate-y-2"
                  initial={{ opacity: 0, y: 30 }}
                  whileInView={{ opacity: 1, y: 0 }}
                  transition={{ duration: 0.6, delay: index * 0.1 }}
                  viewport={{ once: true }}
                >
                  <div className="w-16 h-16 bg-primary/10 rounded-lg flex items-center justify-center mb-6">
                    <service.icon className="text-2xl text-accent" size={32} />
                  </div>
                  <h3 className="text-xl font-semibold font-poppins text-secondary mb-4">
                    {service.title}
                  </h3>
                  <p className="text-gray-600 mb-4">{service.description}</p>
                  <Link href={serviceUrls[service.title as keyof typeof serviceUrls]}>
                    <span className="text-accent font-semibold hover:text-secondary transition-colors cursor-pointer inline-flex items-center">
                      Learn More →
                    </span>
                  </Link>
                </motion.div>
              );
            })}
          </div>
        </div>
      </section>

      {/* Value Proposition */}
      <section className="py-20 bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <motion.div
              initial={{ opacity: 0, x: -50 }}
              whileInView={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.8 }}
              viewport={{ once: true }}
            >
              <h2 className="text-3xl md:text-4xl font-bold font-poppins text-secondary mb-6">
                Why Choose Wassp Marketing?
              </h2>
              <p className="text-lg text-gray-600 mb-8">
                We combine data-driven strategies with creative excellence to deliver marketing solutions that not only look great but perform exceptionally.
              </p>
              <div className="space-y-4">
                {benefits.map((benefit, index) => (
                  <motion.div
                    key={benefit.title}
                    className="flex items-start"
                    initial={{ opacity: 0, x: -30 }}
                    whileInView={{ opacity: 1, x: 0 }}
                    transition={{ duration: 0.6, delay: index * 0.1 }}
                    viewport={{ once: true }}
                  >
                    <div className="w-6 h-6 bg-primary rounded-full flex items-center justify-center mt-1 mr-4">
                      <Check className="text-secondary text-sm" size={16} />
                    </div>
                    <div>
                      <h3 className="font-semibold text-secondary mb-1">{benefit.title}</h3>
                      <p className="text-gray-600">{benefit.description}</p>
                    </div>
                  </motion.div>
                ))}
              </div>
            </motion.div>
            <motion.div
              className="w-full"
              initial={{ opacity: 0, x: 50 }}
              whileInView={{ opacity: 1, x: 0 }}
              transition={{ duration: 0.8 }}
              viewport={{ once: true }}
            >
              <div className="relative h-96 bg-gray-100 flex items-center justify-center overflow-hidden rounded-xl shadow-2xl">
                <video
                  className="w-full h-full object-cover"
                  style={{ width: '800px', height: '600px', maxWidth: '100%', maxHeight: '100%' }}
                  autoPlay
                  muted
                  loop
                  playsInline
                  preload="metadata"
                  onEnded={(e) => {
                    const video = e.target as HTMLVideoElement;
                    video.currentTime = 0;
                    video.play();
                  }}
                >
                  <source src="/attached_assets/Yellow and Orange Playful Animated Business Advertising Mobile Video_1750157994392.mp4" type="video/mp4" />
                  Your browser does not support the video tag.
                </video>
              </div>
            </motion.div>
          </div>
        </div>
      </section>

      {/* Stats Section */}
      <section className="py-20 bg-tertiary">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-8 text-center">
            {stats.map((stat, index) => (
              <motion.div
                key={stat.label}
                className="text-white"
                initial={{ opacity: 0, y: 30 }}
                whileInView={{ opacity: 1, y: 0 }}
                transition={{ duration: 0.6, delay: index * 0.1 }}
                viewport={{ once: true }}
              >
                <div className="text-4xl font-bold font-poppins text-primary mb-2">
                  {stat.number}
                </div>
                <div className="text-light">{stat.label}</div>
              </motion.div>
            ))}
          </div>
        </div>
      </section>

      {/* Customer Testimonials Section */}
      <section className="py-20 bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <motion.div
            className="text-center mb-16"
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-3xl md:text-4xl font-bold font-poppins text-secondary mb-4">
              What Our Customers Say
            </h2>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto mb-8">
              Don't just take our word for it. Here's what our clients have to say about working with Wassp Marketing.
            </p>
          </motion.div>

          {/* Horizontal Scrolling Testimonials */}
          <div className="relative overflow-hidden mb-12 -mx-4 sm:mx-0" id="testimonials-container">
            {/* Left Arrow - Desktop Only */}
            <button
              onClick={() => {
                const container = document.getElementById('testimonials-scroll');
                if (container) {
                  container.scrollLeft -= 300;
                }
              }}
              className="hidden lg:block absolute left-4 top-1/2 -translate-y-1/2 z-10 bg-white/90 hover:bg-white shadow-lg rounded-full p-2 transition-all duration-200 hover:scale-110"
              aria-label="Previous testimonials"
            >
              <ChevronLeft className="w-5 h-5 text-secondary" />
            </button>

            {/* Right Arrow - Desktop Only */}
            <button
              onClick={() => {
                const container = document.getElementById('testimonials-scroll');
                if (container) {
                  container.scrollLeft += 300;
                }
              }}
              className="hidden lg:block absolute right-4 top-1/2 -translate-y-1/2 z-10 bg-white/90 hover:bg-white shadow-lg rounded-full p-2 transition-all duration-200 hover:scale-110"
              aria-label="Next testimonials"
            >
              <ChevronRight className="w-5 h-5 text-secondary" />
            </button>

            <div className="flex gap-4 overflow-x-auto scrollbar-hide pl-4 sm:pl-0" id="testimonials-scroll">
              {(() => {
                const testimonials = [
                  {
                    rating: 5,
                    text: "From the moment we reached out, the team was incredibly professional, attentive, and dedicated to bringing our vision to life. They took the time to understand our needs, and the final designs exceeded my expectations. The attention to detail, creativity, and prompt communication throughout the entire process made it a seamless experience. We would highly recommend Wassp to anyone looking for graphic design solutions!"
                  },
                  {
                    rating: 5,
                    text: "We've had a fantastic experience working with WASSP to create our company website in Portugal. The team is always willing to go the extra mile! They provide great support and expert advice throughout the whole process. Highly recommend!"
                  },
                  {
                    rating: 5,
                    text: "Wassp Advertising is truly a godsend. They take the stress out of marketing and design, allowing our administrators to focus on what we do best. Their creativity and attention to detail shine in every project they handle, delivering eye catching designs and effective campaigns that consistently exceed our expectations."
                  },
                  {
                    rating: 5,
                    text: "Wassp Marketing Solutions has been exceptional in designing and developing our website while generating valuable sales leads. Their professionalism, industry knowledge, and strategic digital marketing insights have significantly boosted our online presence and customer inquiries. Highly recommend their results-driven approach!"
                  },
                  {
                    rating: 5,
                    text: "WASSP's expertise in campaign management is exceptional, delivering highly targeted and well-optimised campaigns across multiple channels. Their meticulous approach to reporting and analytics provides valuable insights, empowering us to make informed decisions. Efficient, professional, and always available, the team is a pleasure to work with. Highly recommended!"
                  },
                  {
                    rating: 5,
                    text: "Absolute amazing team to work with, always on the ball and ready to go the extra mile. Staff is very knowledgeable and willing to teach you new ways to utilize social media in your business."
                  },
                  {
                    rating: 5,
                    text: "Very professional and knowledgeable, always happy to help and assist with any problems. Very friendly staff. Would definitely recommend WASSP."
                  },
                  {
                    rating: 5,
                    text: "Professional and bespoke customer service from the Wassp digital team."
                  },
                  {
                    rating: 5,
                    text: "This group of professionals know their product and live their brand in a way I've not seen in any other agency. If you are lucky to be invited to their office, you'll find yourself stepping into a world that clearly illustrates their expertise and passion. When it comes to a full service advertising and marketing offering, they definitely deliver beyond expectation!"
                  }
                ];
                // Triple the array for seamless infinite scroll
                const tripledTestimonials = [...testimonials, ...testimonials, ...testimonials];
                
                return tripledTestimonials.map((testimonial, index) => (
                  <div
                    key={index}
                    className="flex-shrink-0 w-80 sm:w-72 bg-white rounded-lg shadow-md overflow-hidden hover:shadow-lg transition-shadow duration-300"
                  >
                    <div className="p-4 sm:p-4">
                      <div className="flex items-center mb-3">
                        <div className="flex text-yellow-400">
                          {[...Array(testimonial.rating)].map((_, i) => (
                            <svg key={i} className="w-4 h-4 fill-current" viewBox="0 0 20 20">
                              <path d="M9.049 2.927c.3-.921 1.603-.921 1.902 0l1.07 3.292a1 1 0 00.95.69h3.462c.969 0 1.371 1.24.588 1.81l-2.8 2.034a1 1 0 00-.364 1.118l1.07 3.292c.3.921-.755 1.688-1.54 1.118l-2.8-2.034a1 1 0 00-1.175 0l-2.8 2.034c-.784.57-1.838-.197-1.539-1.118l1.07-3.292a1 1 0 00-.364-1.118L2.98 8.72c-.783-.57-.38-1.81.588-1.81h3.461a1 1 0 00.951-.69l1.07-3.292z"/>
                            </svg>
                          ))}
                        </div>
                      </div>
                      <p className="text-gray-700 text-sm leading-relaxed">{testimonial.text}</p>
                    </div>
                  </div>
                ));
              })()}
            </div>
          </div>

          <motion.div
            className="text-center"
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <div className="flex flex-col sm:flex-row gap-4 justify-center items-center">
              <Link href="/our-results">
                <Button 
                  className="bg-accent text-white px-8 py-4 text-lg font-semibold hover:bg-accent/90 transition-all duration-200"
                  size="lg"
                >
                  View Our Results
                </Button>
              </Link>
              
              <a 
                href="https://www.google.com/maps/place/Wassp/@-26.1656716,28.1477741,17z/data=!4m18!1m9!3m8!1s0x1e95122ffe078139:0x240a4eb93e6c43d3!2sWassp!8m2!3d-26.1656716!4d28.1477741!9m1!1b1!16s%2Fg%2F1thqd46g!3m7!1s0x1e95122ffe078139:0x240a4eb93e6c43d3!8m2!3d-26.1656716!4d28.1477741!9m1!1b1!16s%2Fg%2F1thqd46g?entry=ttu&g_ep=EgoyMDI1MDYxMS4wIKXMDSoASAFQAw%3D%3D"
                target="_blank"
                rel="noopener noreferrer"
                className="bg-white rounded-lg px-6 py-3 hover:bg-gray-50 transition-colors duration-300 flex items-center gap-3"
              >
                <div className="flex items-center gap-2">
                  <svg viewBox="0 0 48 48" className="w-8 h-8">
                    <path fill="#4285F4" d="M24 9.5c3.54 0 6.71 1.22 9.21 3.6l6.85-6.85C35.9 2.38 30.47 0 24 0 14.62 0 6.51 5.38 2.56 13.22l7.98 6.19C12.43 13.72 17.74 9.5 24 9.5z"/>
                    <path fill="#34A853" d="M46.98 24.55c0-1.57-.15-3.09-.38-4.55H24v9.02h12.94c-.58 2.96-2.26 5.48-4.78 7.18l7.73 6c4.51-4.18 7.09-10.36 7.09-17.65z"/>
                    <path fill="#FBBC05" d="M10.53 28.59c-.48-1.45-.76-2.99-.76-4.59s.27-3.14.76-4.59l-7.98-6.19C.92 16.46 0 20.12 0 24c0 3.88.92 7.54 2.56 10.78l7.97-6.19z"/>
                    <path fill="#EA4335" d="M24 48c6.48 0 11.93-2.13 15.89-5.81l-7.73-6c-2.15 1.45-4.92 2.3-8.16 2.3-6.26 0-11.57-4.22-13.47-9.91l-7.98 6.19C6.51 42.62 14.62 48 24 48z"/>
                  </svg>
                  <div className="text-left">
                    <div className="text-sm font-medium text-gray-800">Google Review Rating</div>
                    <div className="flex items-center gap-1">
                      <span className="text-lg font-bold text-orange-500">4.9</span>
                      <div className="flex text-orange-400">
                        {[...Array(5)].map((_, i) => (
                          <svg key={i} className="w-4 h-4 fill-current" viewBox="0 0 20 20">
                            <path d="M9.049 2.927c.3-.921 1.603-.921 1.902 0l1.07 3.292a1 1 0 00.95.69h3.462c.969 0 1.371 1.24.588 1.81l-2.8 2.034a1 1 0 00-.364 1.118l1.07 3.292c.3.921-.755 1.688-1.54 1.118l-2.8-2.034a1 1 0 00-1.175 0l-2.8 2.034c-.784.57-1.838-.197-1.539-1.118l1.07-3.292a1 1 0 00-.364-1.118L2.98 8.72c-.783-.57-.38-1.81.588-1.81h3.461a1 1 0 00.951-.69l1.07-3.292z"/>
                          </svg>
                        ))}
                      </div>
                    </div>
                  </div>
                </div>
              </a>
            </div>
          </motion.div>
        </div>
      </section>

      {/* Ready to Unlock Growth CTA Section */}
      <section className="py-20 bg-secondary">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <motion.div
            initial={{ opacity: 0, y: 30 }}
            whileInView={{ opacity: 1, y: 0 }}
            transition={{ duration: 0.6 }}
            viewport={{ once: true }}
          >
            <h2 className="text-3xl md:text-4xl font-bold font-poppins text-white mb-4">
              Ready to Unlock Growth?
            </h2>
            <p className="text-xl text-white/90 mb-8">
              Let's start your digital transformation today.
            </p>
            <Link href="/contact">
              <Button 
                className="bg-accent text-white hover:bg-accent/90 hover:scale-105 transition-all duration-300 px-8 py-4 text-lg font-semibold"
                size="lg"
              >
                Hire Us
              </Button>
            </Link>
          </motion.div>
        </div>
      </section>
    </div>
  );
};

export default Home;
